[libpng15] Imported from libpng-1.5.28rc01.tar
diff --git a/ANNOUNCE b/ANNOUNCE
index 5300c75..d021503 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
 
-Libpng 1.5.28beta01 - December 27, 2016
+Libpng 1.5.28rc01 - December 27, 2016
 
 This is not intended to be a public release.  It will be replaced
 within a few weeks by a public version or by another test version.
@@ -9,24 +9,24 @@
 Source files with LF line endings (for Unix/Linux) and with a
 "configure" script
 
-   1.5.28beta01.tar.xz (LZMA-compressed, recommended)
-   1.5.28beta01.tar.gz
+   1.5.28rc01.tar.xz (LZMA-compressed, recommended)
+   1.5.28rc01.tar.gz
 
 Source files with CRLF line endings (for Windows), without the
 "configure" script
 
-   lp1528b01.7z  (LZMA-compressed, recommended)
-   lp1528b01.zip
+   lp1528r01.7z  (LZMA-compressed, recommended)
+   lp1528r01.zip
 
 Other information:
 
-   1.5.28beta01-README.txt
-   1.5.28beta01-LICENSE.txt
-   libpng-1.5.28beta01-*.asc (armored detached GPG signatures)
+   1.5.28rc01-README.txt
+   1.5.28rc01-LICENSE.txt
+   libpng-1.5.28rc01-*.asc (armored detached GPG signatures)
 
 Changes since the last public release (1.5.27):
 
-version 1.5.28beta01 [December 27, 2016]
+version 1.5.28rc01 [December 27, 2016]
   Merged with current libpng16 gregbook, pngvalid.c, pngtest.c, pngminim,
     pngminus
   Fixed undefined behavior in png_push_save_buffer(). Do not call
diff --git a/CHANGES b/CHANGES
index 909e644..ba4643b 100644
--- a/CHANGES
+++ b/CHANGES
@@ -4496,7 +4496,7 @@
 version 1.5.27 [May 26, 2016]
   No changes.
 
-version 1.5.28beta01 [December 27, 2016]
+version 1.5.28rc01 [December 27, 2016]
   Merged with current libpng16 gregbook, pngvalid.c, pngtest.c, pngminim,
     pngminus
   Fixed undefined behavior in png_push_save_buffer(). Do not call
@@ -4521,12 +4521,11 @@
     Since signed overflow is undefined in C90 the code has been modified to
     correctly calculate a signed result.  This requires changing the 'hi'
     result parameter to a signed value.
-
-This has been code reviewed solely by the author.  A further code review
-is highly desireable.  Nevertheless the code compiles without warnings
-from clang and without the prior detection of an overflow.  Since it no
-longer truncates any of the intermediate values this should be enough to
-ensure that it is correct.
+  This has been code reviewed solely by the author.  A further code review
+    is highly desireable.  Nevertheless the code compiles without warnings
+    from clang and without the prior detection of an overflow.  Since it no
+    longer truncates any of the intermediate values this should be enough to
+    ensure that it is correct.
 
 Send comments/corrections/commendations to png-mng-implement at lists.sf.net
 (subscription required; visit
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 4d793bf..6b7be89 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -535,7 +535,7 @@
 # SET UP LINKS
 if(PNG_SHARED)
   set_target_properties(png PROPERTIES
-#   VERSION 15.${PNGLIB_RELEASE}.1.5.28beta01
+#   VERSION 15.${PNGLIB_RELEASE}.1.5.28rc01
     VERSION 15.${PNGLIB_RELEASE}.0
     SOVERSION 15
     CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index d60df54..4909f23 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.0.7, July 1, 2000, through 1.5.28beta01, May 29, 2016, are
+libpng versions 1.0.7, July 1, 2000, through 1.5.28rc01, December 27, 2016, are
 Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
 derived from libpng-1.0.6, and are distributed according to the same
 disclaimer and license as libpng-1.0.6 with the following individuals
@@ -119,4 +119,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-May 29, 2016
+December 27, 2016
diff --git a/README b/README
index 0a55641..7fbf055 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.28beta01 - May 29, 2016 (shared library 15.0)
+README for libpng version 1.5.28rc01 - December 27, 2016 (shared library 15.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/TODO b/TODO
index 0b3b651..08ce282 100644
--- a/TODO
+++ b/TODO
@@ -22,7 +22,6 @@
   background and doing rgb-to-gray transformation.
 Investigate pre-incremented loop counters and other loop constructions.
 Add interpolated method of handling interlacing.
-Switch to the simpler zlib (zlib/libpng) license if legally possible.
 Extend pngvalid.c to validate more of the libpng transformations.
 
 */
diff --git a/configure b/configure
index 6358a73..c01a320 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for libpng 1.5.28beta01.
+# Generated by GNU Autoconf 2.69 for libpng 1.5.28rc01.
 #
 # Report bugs to <png-mng-implement@lists.sourceforge.net>.
 #
@@ -590,8 +590,8 @@
 # Identity of this package.
 PACKAGE_NAME='libpng'
 PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.5.28beta01'
-PACKAGE_STRING='libpng 1.5.28beta01'
+PACKAGE_VERSION='1.5.28rc01'
+PACKAGE_STRING='libpng 1.5.28rc01'
 PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
 PACKAGE_URL=''
 
@@ -1354,7 +1354,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures libpng 1.5.28beta01 to adapt to many kinds of systems.
+\`configure' configures libpng 1.5.28rc01 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1424,7 +1424,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of libpng 1.5.28beta01:";;
+     short | recursive ) echo "Configuration of libpng 1.5.28rc01:";;
    esac
   cat <<\_ACEOF
 
@@ -1579,7 +1579,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-libpng configure 1.5.28beta01
+libpng configure 1.5.28rc01
 generated by GNU Autoconf 2.69
 
 Copyright (C) 2012 Free Software Foundation, Inc.
@@ -2002,7 +2002,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by libpng $as_me 1.5.28beta01, which was
+It was created by libpng $as_me 1.5.28rc01, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   $ $0 $@
@@ -2865,7 +2865,7 @@
 
 # Define the identity of the package.
  PACKAGE='libpng'
- VERSION='1.5.28beta01'
+ VERSION='1.5.28rc01'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -2982,7 +2982,7 @@
 
 
 
-PNGLIB_VERSION=1.5.28beta01
+PNGLIB_VERSION=1.5.28rc01
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=5
 PNGLIB_RELEASE=28
@@ -14124,7 +14124,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by libpng $as_me 1.5.28beta01, which was
+This file was extended by libpng $as_me 1.5.28rc01, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -14190,7 +14190,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-libpng config.status 1.5.28beta01
+libpng config.status 1.5.28rc01
 configured by $0, generated by GNU Autoconf 2.69,
   with options \\"\$ac_cs_config\\"
 
diff --git a/configure.ac b/configure.ac
index 48c9bc7..588c4ca 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,12 +18,12 @@
 
 dnl Version number stuff here:
 
-AC_INIT([libpng], [1.5.28beta01], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.5.28rc01], [png-mng-implement@lists.sourceforge.net])
 AM_INIT_AUTOMAKE([1.13 serial-tests subdir-objects])
 dnl stop configure from automagically running automake
 AM_MAINTAINER_MODE
 
-PNGLIB_VERSION=1.5.28beta01
+PNGLIB_VERSION=1.5.28rc01
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=5
 PNGLIB_RELEASE=28
diff --git a/contrib/libtests/pngvalid.c b/contrib/libtests/pngvalid.c
index 330e263..b0b75b9 100644
--- a/contrib/libtests/pngvalid.c
+++ b/contrib/libtests/pngvalid.c
@@ -1,7 +1,7 @@
 
 /* pngvalid.c - validate libpng by constructing then reading png files.
  *
- * Last changed in libpng 1.6.26 [October 20, 2016]
+ * Last changed in libpng 1.6.27 [(PENDING RELEASE)]
  * Copyright (c) 2014-2016 John Cunningham Bowler
  *
  * This code is released under the libpng license.
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 6ed8fe1..32c2761 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 Libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.28beta01 - May 29, 2016
+ libpng version 1.5.28rc01 - December 27, 2016
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.28beta01 - May 29, 2016
+ libpng versions 0.97, January 1998, through 1.5.28rc01 - December 27, 2016
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2014 Glenn Randers-Pehrson
 
@@ -533,7 +533,7 @@
 passed in row number, and pass will always be 0.  For the interlaced case the
 same applies unless the row value is 0, in which case the row just handled was
 the last one from one of the preceding passes.  Because interlacing may skip a
-pass you cannot be sure that the preceding pass is just 'pass-1', if you really
+pass you cannot be sure that the preceding pass is just 'pass-1'; if you really
 need to know what the last pass is record (row,pass) from the callback and use
 the last recorded value each time.
 
@@ -4516,7 +4516,7 @@
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.28beta01 are Y2K compliant.  It is my belief that earlier
+upward through 1.5.28rc01 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has two year fields.  One is a 2-byte unsigned integer
diff --git a/libpng.3 b/libpng.3
index cf4a27c..7ab9f17 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "May 29, 2016"
+.TH LIBPNG 3 "December 27, 2016"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.28beta01
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.28rc01
 .SH SYNOPSIS
 \fB
 #include <png.h>\fP
@@ -496,7 +496,7 @@
 .SH LIBPNG.TXT
 Libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.28beta01 - May 29, 2016
+ libpng version 1.5.28rc01 - December 27, 2016
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -507,7 +507,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.28beta01 - May 29, 2016
+ libpng versions 0.97, January 1998, through 1.5.28rc01 - December 27, 2016
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2014 Glenn Randers-Pehrson
 
@@ -1029,7 +1029,7 @@
 passed in row number, and pass will always be 0.  For the interlaced case the
 same applies unless the row value is 0, in which case the row just handled was
 the last one from one of the preceding passes.  Because interlacing may skip a
-pass you cannot be sure that the preceding pass is just 'pass\-1', if you really
+pass you cannot be sure that the preceding pass is just 'pass\-1'; if you really
 need to know what the last pass is record (row,pass) from the callback and use
 the last recorded value each time.
 
@@ -5012,7 +5012,7 @@
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.28beta01 are Y2K compliant.  It is my belief that earlier
+upward through 1.5.28rc01 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has two year fields.  One is a 2-byte unsigned integer
@@ -5167,7 +5167,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.5.28beta01 - May 29, 2016:
+Libpng version 1.5.28rc01 - December 27, 2016:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -5192,7 +5192,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.0.7, July 1, 2000, through 1.5.28beta01, May 29, 2016, are
+libpng versions 1.0.7, July 1, 2000, through 1.5.28rc01, December 27, 2016, are
 Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
 derived from libpng-1.0.6, and are distributed according to the same
 disclaimer and license as libpng-1.0.6 with the following individuals
@@ -5309,7 +5309,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-May 29, 2016
+December 27, 2016
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index 6578af2..d4b23e0 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "May 29, 2016"
+.TH LIBPNGPF 3 "December 27, 2016"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.28beta01
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.28rc01
 (private functions)
 .SH SYNOPSIS
 \fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index 62bd8c3..b7265dd 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "May 29, 2016"
+.TH PNG 5 "December 27, 2016"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
@@ -35,7 +35,7 @@
 RFC 2083
 .IP
 .br
-ftp://ds.internic.net/rfc/rfc2083.txt
+http://www.ietf.org/rfc/rfc2083.txt
 .br
 or (as a W3C Recommendation) at
 .br
diff --git a/png.c b/png.c
index 0e39420..341ac2a 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
 #include "pngpriv.h"
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_28beta01 Your_png_h_is_not_version_1_5_28beta01;
+typedef png_libpng_version_1_5_28rc01 Your_png_h_is_not_version_1_5_28rc01;
 
 /* Tells libpng that we have already handled the first "num_bytes" bytes
  * of the PNG file signature.  If the PNG data is embedded into another
@@ -655,14 +655,14 @@
 #else
 #  ifdef __STDC__
    return PNG_STRING_NEWLINE \
-     "libpng version 1.5.28beta01 - December 27, 2016" PNG_STRING_NEWLINE \
+     "libpng version 1.5.28rc01 - December 27, 2016" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson" \
      PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE;
 #  else
-      return "libpng version 1.5.28beta01 - December 27, 2016\
+      return "libpng version 1.5.28rc01 - December 27, 2016\
       Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index cb481f4..82df64d 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.5.28beta01, May 29, 2016
+ * libpng version 1.5.28rc01, December 27, 2016
  *
  * Copyright (c) 1998-2002,2004,2006-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index 57f141e..e0c41a0 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -2083,4 +2083,4 @@
 #endif
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_28beta01 Your_png_h_is_not_version_1_5_28beta01;
+typedef png_libpng_version_1_5_28rc01 Your_png_h_is_not_version_1_5_28rc01;
diff --git a/projects/vstudio/README.txt b/projects/vstudio/README.txt
index 0558134..e542fc7 100644
--- a/projects/vstudio/README.txt
+++ b/projects/vstudio/README.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.5.28beta01 - May 29, 2016
+libpng version 1.5.28rc01 - December 27, 2016
 
 Copyright (c) 2010,2013,2016 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 559a625..78ed3dc 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.5.28beta01 - May 29, 2016
+ * libpng version 1.5.28rc01 - December 27, 2016
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index a1e31e3..354de06 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
 
-Makefiles for  libpng version 1.5.28beta01 - May 29, 2016
+Makefiles for  libpng version 1.5.28rc01 - December 27, 2016
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
-                       (gcc, creates libpng15.so.15.1.5.28beta01)
+                       (gcc, creates libpng15.so.15.1.5.28rc01)
  makefile.gcc      =>  Generic makefile (gcc, creates static libpng.a)
  makefile.knr      =>  Archaic UNIX Makefile that converts files with
                        ansi2knr (Requires ansi2knr.c from
@@ -34,12 +34,12 @@
  makefile.os2      =>  OS/2 Makefile (gcc and emx, requires libpng.def)
  makefile.sco      =>  For SCO OSr5  ELF and Unixware 7 with Native cc
  makefile.sggcc    =>  Silicon Graphics (gcc,
-                       creates libpng15.so.15.1.5.28beta01)
+                       creates libpng15.so.15.1.5.28rc01)
  makefile.sgi      =>  Silicon Graphics IRIX makefile (cc, creates static lib)
  makefile.solaris  =>  Solaris 2.X makefile (gcc,
-                       creates libpng15.so.15.1.5.28beta01)
+                       creates libpng15.so.15.1.5.28rc01)
  makefile.so9      =>  Solaris 9 makefile (gcc,
-                       creates libpng15.so.15.1.5.28beta01)
+                       creates libpng15.so.15.1.5.28rc01)
  makefile.std      =>  Generic UNIX makefile (cc, creates static libpng.a)
  makefile.sunos    =>  Sun makefile
  makefile.32sunu   =>  Sun Ultra 32-bit makefile
diff --git a/scripts/def.c b/scripts/def.c
index 43c932d..f29b520 100644
--- a/scripts/def.c
+++ b/scripts/def.c
@@ -21,7 +21,7 @@
 PNG_DFN "OS2 CODE PRELOAD MOVEABLE DISCARDABLE"
 PNG_DFN ""
 PNG_DFN "EXPORTS"
-PNG_DFN ";Version 1.5.28beta01"
+PNG_DFN ";Version 1.5.28rc01"
 
 #define PNG_EXPORTA(ordinal, type, name, args, attributes)\
         PNG_DFN "@" SYMBOL_PREFIX "@@" name "@"
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 774bf58..6f14d3d 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
 
 # Modeled after libxml-config.
 
-version=1.5.28beta01
+version=1.5.28rc01
 prefix=""
 libdir=""
 libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 12fae90..b143de1 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@
 
 Name: libpng
 Description: Loads and saves PNG files
-Version: 1.5.28beta01
+Version: 1.5.28rc01
 Libs: -L${libdir} -lpng15
 Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 35e85eb..976ac05 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@
 
 LIB=	png15
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.5.28beta01
+SHLIB_MINOR=	1.5.28rc01
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index 3ffcf14..2df4568 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@
 
 LIB=	png
 SHLIB_MAJOR=	15
-SHLIB_MINOR=	1.5.28beta01
+SHLIB_MINOR=	1.5.28rc01
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index fd42f94..57cf988 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@
 MANDIR= ${PREFIX}/man/cat
 
 SHLIB_MAJOR=	15
-SHLIB_MINOR=	1.5.28beta01
+SHLIB_MINOR=	1.5.28rc01
 
 LIB=	png
 SRCS=	png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 5c772b6..5262183 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -1,7 +1,7 @@
-/* 1.5.28beta01 STANDARD API DEFINITION */
+/* 1.5.28rc01 STANDARD API DEFINITION */
 /* pnglibconf.h - library build configuration */
 
-/* libpng version 1.5.28beta01 - May 29, 2016 */
+/* libpng version 1.5.28rc01 - December 27, 2016 */
 
 /* Copyright (c) 2011-2015 Glenn Randers-Pehrson */
 
diff --git a/scripts/symbols.def b/scripts/symbols.def
index 537b735..3caf451 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -1,4 +1,4 @@
-;Version 1.5.28beta01
+;Version 1.5.28rc01
 ;--------------------------------------------------------------
 ; LIBPNG symbol list as a Win32 DEF file
 ; Contains all the symbols that can be exported from libpng
diff --git a/png.h b/png.h
index 6fc6e73..74280ad 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.5.28beta01, May 29, 2016
  *
  * Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.5.28beta01, May 29, 2016:
  *     Glenn Randers-Pehrson.
  *   See also "Contributing Authors", below.
  */
@@ -25,7 +25,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.0.7, July 1, 2000, through 1.5.28beta01, May 29, 2016, are
  * Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
  * derived from libpng-1.0.6, and are distributed according to the same
  * disclaimer and license as libpng-1.0.6 with the following individuals
@@ -228,13 +228,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    May 29, 2016
+ *    December 27, 2016
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.5.28beta01 are Y2K compliant.  It is my belief that
  *    earlier versions were also Y2K compliant.
  *
  *    Libpng only has two year fields.  One is a 2-byte unsigned integer
@@ -295,9 +295,9 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.28beta01"
+#define PNG_LIBPNG_VER_STRING "1.5.28rc01"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.5.28beta01 - May 29, 2016\n"
+     " libpng version 1.5.28rc01 - December 27, 2016\n"
 
 #define PNG_LIBPNG_VER_SONUM   15
 #define PNG_LIBPNG_VER_DLLNUM  15
@@ -328,7 +328,7 @@
 #define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
                                        PNG_LIBPNG_BUILD_PRIVATE */
 
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_BETA
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_RC
 
 /* Careful here.  At one time, Guy wanted to use 082, but that would be octal.
  * We must not include leading zeros.
@@ -458,7 +458,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef char* png_libpng_version_1_5_28beta01;
+typedef char* png_libpng_version_1_5_28rc01;
 
 /* Three color definitions.  The order of the red, green, and blue, (and the
  * exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.5.28beta01, May 29, 2016
+ * libpng version 1.5.28rc01, December 27, 2016
  *
  * Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.5.28beta01, May 29, 2016:
+ *   libpng versions 0.97, January 1998, through 1.5.28rc01, December 27, 2016:
  *     Glenn Randers-Pehrson.
  *   See also "Contributing Authors", below.
@@ -25,7 +25,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.0.7, July 1, 2000, through 1.5.28beta01, May 29, 2016, are
+ * libpng versions 1.0.7, July 1, 2000, through 1.5.28rc01, December 27, 2016, are
  * Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
  * derived from libpng-1.0.6, and are distributed according to the same
@@ -228,13 +228,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.5.28beta01 are Y2K compliant.  It is my belief that
+ *    upward through 1.5.28rc01 are Y2K compliant.  It is my belief that
  *    earlier versions were also Y2K compliant.
  *